@@ -1,6 +1,6 @@
 /***********************************************************************
  *
- * Copyright (C) 2009, 2010, 2011, 2012, 2013, 2014 Graeme Gott <graeme@gottcode.org>
+ * Copyright (C) 2009, 2010, 2011, 2012, 2013, 2014, 2016 Graeme Gott <graeme@gottcode.org>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,6 +36,7 @@ class Theme;
 #include <QWidget>
 class QGridLayout;
 class QScrollBar;
+class QPrinter;
 class QTextEdit;
 class QTimer;
 
@@ -69,9 +70,9 @@ public:
 	void reload(bool prompt = true);
 	void close();
 	void checkSpelling();
-	void print();
+	void print(QPrinter* printer);
 	bool loadFile(const QString& filename, int position);
-	void loadTheme(const Theme& theme, const QBrush& foreground);
+	void loadTheme(const Theme& theme);
 	void loadPreferences();
 	void setFocusMode(int focus_mode);
 	void setModified(bool modified);
