@@ -1,6 +1,6 @@
 /***********************************************************************
  *
- * Copyright (C) 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017 Graeme Gott <graeme@gottcode.org>
+ * Copyright (C) 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018 Graeme Gott <graeme@gottcode.org>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -61,7 +61,6 @@
 #include <QPlainTextEdit>
 #include <QScrollBar>
 #include <QSettings>
-#include <QSignalMapper>
 #include <QSizeGrip>
 #include <QStandardPaths>
 #include <QTabBar>
@@ -93,7 +92,6 @@ Window::Window(const QStringList& command_line_files) :
 	m_key_sound(0),
 	m_enter_key_sound(0),
 	m_fullscreen(true),
-	m_auto_save(true),
 	m_save_positions(true)
 {
 	setAcceptDrops(true);
@@ -160,7 +158,7 @@ Window::Window(const QStringList& command_line_files) :
 
 	// Set up cache timer
 	m_save_timer = new QTimer(this);
-	m_save_timer->setInterval(600000);
+	m_save_timer->setInterval(300000);
 	connect(m_save_timer, SIGNAL(timeout()), m_daily_progress, SLOT(save()));
 
 	// Set up details
@@ -229,16 +227,13 @@ Window::Window(const QStringList& command_line_files) :
 	addAction(action);
 	ActionManager::instance()->addAction("SwitchLastDocument", action);
 
-	QSignalMapper* mapper = new QSignalMapper(this);
 	for (int i = 2; i < 10 ; ++i) {
 		action = new QAction(tr("Switch to Document %1").arg(i), this);
 		action->setShortcut(Qt::CTRL + Qt::Key_0 + i);
-		connect(action, SIGNAL(triggered()), mapper, SLOT(map()));
-		mapper->setMapping(action, i - 1);
+		connect(action, &QAction::triggered, [=] { m_tabs->setCurrentIndex(i - 1); });
 		addAction(action);
 		ActionManager::instance()->addAction(QString("SwitchDocument%1").arg(i), action);
 	}
-	connect(mapper, SIGNAL(mapped(int)), m_tabs, SLOT(setCurrentIndex(int)));
 
 	// Always bring interface to front
 	connect(m_documents, SIGNAL(headerVisible(bool)), menuBar(), SLOT(raise()));
@@ -318,19 +313,26 @@ Window::Window(const QStringList& command_line_files) :
 		// Read mapping of cached files
 		m_document_cache->parseMapping(files, datafiles);
 
-		// Ask if they want to use cached files
-		if (!files.isEmpty()) {
-			QStringList filenames;
-			int untitled = 1;
-			int count = files.count();
-			for (int i = 0; i < count; ++i) {
-				if (!files.at(i).isEmpty()) {
-					filenames.append(QDir::toNativeSeparators(files.at(i)));
-				} else {
-					filenames.append(tr("(Untitled %1)").arg(untitled));
-					untitled++;
+		// Find proper names of cache files
+		QStringList filenames;
+		int untitled = 1;
+		for (int i = 0, count = files.count(); i < count; ++i) {
+			if (!files.at(i).isEmpty()) {
+				// Ignore empty cache files
+				if (QFileInfo(datafiles.at(i)).size() == 0) {
+					datafiles[i] = files[i];
+					continue;
 				}
+
+				filenames.append(QDir::toNativeSeparators(files.at(i)));
+			} else {
+				filenames.append(tr("(Untitled %1)").arg(untitled));
+				untitled++;
 			}
+		}
+
+		// Ask if they want to use cached files
+		if (!filenames.isEmpty()) {
 			m_load_screen->setText("");
 			QMessageBox mbox(window());
 			mbox.setWindowTitle(tr("Warning"));
@@ -859,7 +861,7 @@ void Window::aboutClicked()
 		"<p align='center'>%6<br/><small>%7</small></p>")
 		.arg(tr("FocusWriter"), QApplication::applicationVersion(),
 			tr("A simple fullscreen word processor"),
-			tr("Copyright &copy; 2008-%1 Graeme Gott").arg("2017"),
+			tr("Copyright &copy; 2008-%1 Graeme Gott").arg("2018"),
 			tr("Released under the <a href=%1>GPL 3</a> license").arg("\"http://www.gnu.org/licenses/gpl.html\""),
 			tr("Uses icons from the <a href=%1>Oxygen</a> icon theme").arg("\"http://www.oxygen-icons.org/\""),
 			tr("Used under the <a href=%1>LGPL 3</a> license").arg("\"http://www.gnu.org/licenses/lgpl.html\""))
@@ -1109,11 +1111,6 @@ bool Window::saveDocument(int index)
 		return true;
 	}
 
-	// Auto-save document
-	if (m_auto_save && document->isModified() && !document->filename().isEmpty()) {
-		return document->save();
-	}
-
 	// Prompt about saving changes
 	QMessageBox mbox(window());
 	mbox.setWindowTitle(tr("Save Changes?"));
@@ -1159,14 +1156,6 @@ void Window::loadPreferences()
 	}
 	Sound::setEnabled(Preferences::instance().typewriterSounds());
 
-	m_auto_save = Preferences::instance().autoSave();
-	if (m_auto_save) {
-		disconnect(m_save_timer, SIGNAL(timeout()), m_documents, SLOT(autoCache()));
-		connect(m_save_timer, SIGNAL(timeout()), m_documents, SLOT(autoSave()));
-	} else {
-		disconnect(m_save_timer, SIGNAL(timeout()), m_documents, SLOT(autoSave()));
-		connect(m_save_timer, SIGNAL(timeout()), m_documents, SLOT(autoCache()));
-	}
 	m_save_positions = Preferences::instance().savePositions();
 
 	SmartQuotes::loadPreferences();
@@ -1346,20 +1335,17 @@ void Window::initMenus()
 	headings[6] = headings_menu->addAction(tr("Heading &6"));
 	headings[0] = headings_menu->addAction(tr("&Normal"));
 	m_headings_actions = new QActionGroup(this);
-	QSignalMapper* headings_mapper = new QSignalMapper(this);
 	for (int i = 0; i < 7; ++i) {
 		headings[i]->setCheckable(true);
 		headings[i]->setData(i);
 		m_headings_actions->addAction(headings[i]);
-		connect(headings[i], SIGNAL(triggered()), headings_mapper, SLOT(map()));
-		headings_mapper->setMapping(headings[i], i);
+		connect(headings[i], &QAction::triggered, [=] { m_documents->setBlockHeading(i); });
 	}
 	for (int i = 1; i < 7; ++i) {
 		ActionManager::instance()->addAction(QString("FormatBlockHeading%1").arg(i), headings[i]);
 	}
 	ActionManager::instance()->addAction(QString("FormatBlockNormal"), headings[0]);
 	headings[0]->setChecked(true);
-	connect(headings_mapper, SIGNAL(mapped(int)), m_documents, SLOT(setBlockHeading(int)));
 
 	format_menu->addSeparator();
 	m_actions["FormatBold"] = format_menu->addAction(QIcon::fromTheme("format-text-bold"), tr("&Bold"), m_documents, SLOT(setFontBold(bool)), QKeySequence::Bold);
