@@ -502,10 +502,6 @@
         <source>Saving</source>
         <translation>حفـظ</translation>
     </message>
-    <message>
-        <source>Automatically save changes</source>
-        <translation>حفظ تلقائي للتغييرات</translation>
-    </message>
     <message>
         <source>Remember cursor position</source>
         <translation type="unfinished"></translation>
