@@ -166,7 +166,7 @@
     </message>
     <message>
         <source>Saving as plain text will discard all formatting. Discard formatting?</source>
-        <translation>Durch das Soeichern als einfacher Text werden alle Formatierungen entfernt. Formatierungen entfernen?</translation>
+        <translation>Durch das Speichern als einfacher Text werden alle Formatierungen entfernt. Formatierungen entfernen?</translation>
     </message>
 </context>
 <context>
@@ -478,10 +478,6 @@
         <source>Saving</source>
         <translation>Speichern</translation>
     </message>
-    <message>
-        <source>Automatically save changes</source>
-        <translation>Änderungen automatisch speichern</translation>
-    </message>
     <message>
         <source>Remember cursor position</source>
         <translation>Position der Eingabemarkierung merken</translation>
