@@ -289,7 +289,7 @@
     </message>
     <message>
         <source>OpenDocument Flat XML</source>
-        <translation type="unfinished"></translation>
+        <translation>Litteä OpenDocument-XML</translation>
     </message>
     <message>
         <source>Office Open XML</source>
@@ -478,10 +478,6 @@
         <source>Saving</source>
         <translation>Tallennus</translation>
     </message>
-    <message>
-        <source>Automatically save changes</source>
-        <translation>Tallenna muutokset automaattisesti</translation>
-    </message>
     <message>
         <source>Remember cursor position</source>
         <translation>Muista kohdistimen sijainti</translation>
@@ -520,7 +516,7 @@
     </message>
     <message>
         <source>Remove current dictionary?</source>
-        <translation type="unfinished"></translation>
+        <translation>Poistetaanko nykyinen sanakirja?</translation>
     </message>
     <message>
         <source>Write byte order mark in plain text files</source>
@@ -532,19 +528,19 @@
     </message>
     <message>
         <source>User Interface</source>
-        <translation type="unfinished"></translation>
+        <translation>Käyttöliittymä</translation>
     </message>
     <message>
         <source>Always show scrollbar</source>
-        <translation type="unfinished"></translation>
+        <translation>Näytä vierityspalkki aina</translation>
     </message>
     <message>
         <source>Always show top bar</source>
-        <translation type="unfinished"></translation>
+        <translation>Näytä yläpalkki aina</translation>
     </message>
     <message>
         <source>Always show bottom bar</source>
-        <translation type="unfinished"></translation>
+        <translation>Näytä alapalkki aina</translation>
     </message>
     <message>
         <source>Reset Today</source>
@@ -1119,11 +1115,11 @@
     </message>
     <message>
         <source>Bitter Skies</source>
-        <translation type="unfinished"></translation>
+        <translation>Karvaat taivaat</translation>
     </message>
     <message>
         <source>Enchantment</source>
-        <translation type="unfinished"></translation>
+        <translation>Lumous</translation>
     </message>
     <message>
         <source>Gentle Blues</source>
@@ -1139,11 +1135,11 @@
     </message>
     <message>
         <source>Spy Games</source>
-        <translation type="unfinished"></translation>
+        <translation>Vakoojaleikit</translation>
     </message>
     <message>
         <source>Tranquility</source>
-        <translation type="unfinished"></translation>
+        <translation>Rauha</translation>
     </message>
     <message>
         <source>Writing Desk</source>
@@ -1503,7 +1499,7 @@
     </message>
     <message>
         <source>Pa&amp;ge Setup...</source>
-        <translation type="unfinished"></translation>
+        <translation>Sivuasetukset...</translation>
     </message>
     <message>
         <source>&amp;Close</source>
@@ -1723,7 +1719,7 @@
     </message>
     <message>
         <source>Update Document Smart Quotes</source>
-        <translation type="unfinished"></translation>
+        <translation>Päivitä dokumentin älykkäät lainausmerkit</translation>
     </message>
     <message>
         <source>Update &amp;Selection</source>
@@ -1731,7 +1727,7 @@
     </message>
     <message>
         <source>Update Selection Smart Quotes</source>
-        <translation type="unfinished"></translation>
+        <translation>Päivitä valinnan älykkäät lainausmerkit</translation>
     </message>
     <message>
         <source>&amp;Spelling...</source>
@@ -1823,7 +1819,7 @@
     </message>
     <message>
         <source>Ctrl+Shift+`</source>
-        <translation type="unfinished"></translation>
+        <translation>Ctrl+Shift+`</translation>
     </message>
     <message>
         <source>&amp;Help</source>
