@@ -478,10 +478,6 @@
         <source>Saving</source>
         <translation>שמירה</translation>
     </message>
-    <message>
-        <source>Automatically save changes</source>
-        <translation>שמור שינויים אוטומטית</translation>
-    </message>
     <message>
         <source>Remember cursor position</source>
         <translation>זכור מיקום סמן</translation>
