@@ -478,10 +478,6 @@
         <source>Saving</source>
         <translation>Opslaan</translation>
     </message>
-    <message>
-        <source>Automatically save changes</source>
-        <translation>Automatisch veranderingen opslaan</translation>
-    </message>
     <message>
         <source>Remember cursor position</source>
         <translation>Onthou cursor positie</translation>
