@@ -478,10 +478,6 @@
         <source>Saving</source>
         <translation>Gravando</translation>
     </message>
-    <message>
-        <source>Automatically save changes</source>
-        <translation>Gravar automaticamente as alterações</translation>
-    </message>
     <message>
         <source>Remember cursor position</source>
         <translation>Memorizar a posição do cursor</translation>
