@@ -478,10 +478,6 @@
         <source>Saving</source>
         <translation>Spara</translation>
     </message>
-    <message>
-        <source>Automatically save changes</source>
-        <translation>Spara automatiskt ändringar</translation>
-    </message>
     <message>
         <source>Remember cursor position</source>
         <translation>Kom ihåg markörposition</translation>
